@@ -1,27 +1,33 @@
 """
 Composite repository implementation.
+
+This implements a composite pattern for repositories.
 """
 from typing import Any, Generic, List, Optional, TypeVar
 
 from .mapper import Mapper
-from .repository import _A, _I, _R, _U, Repository, _Id
+from .repository import Repository
 
-_Repo = TypeVar("_Repo", bound=Repository)
-_MappedItem = TypeVar("_MappedItem")
-_MappedCreate = TypeVar("_MappedCreate")
-_MappedUpdate = TypeVar("_MappedUpdate")
-_MappedReplace = TypeVar("_MappedReplace")
-_MappedId = TypeVar("_MappedId")
+_MI = TypeVar("_MI")
+_MA = TypeVar("_MA")
+_MU = TypeVar("_MU")
+_MR = TypeVar("_MR")
+_MId = TypeVar("_MId")
+_A = TypeVar("_A")
+_U = TypeVar("_U")
+_R = TypeVar("_R")
+_I = TypeVar("_I")
+_Id = TypeVar("_Id")
 
 
 class MappedRepository(
-    Repository[_MappedId, _MappedCreate, _MappedUpdate, _MappedReplace, _MappedItem],
+    Repository[_MId, _MA, _MU, _MR, _MI],
     Generic[
-        _MappedId,
-        _MappedCreate,
-        _MappedUpdate,
-        _MappedReplace,
-        _MappedItem,
+        _MId,
+        _MA,
+        _MU,
+        _MR,
+        _MI,
         _Id,
         _A,
         _U,
@@ -39,14 +45,13 @@ class MappedRepository(
         self,
         repository: Repository[_Id, _A, _U, _R, _I],
         *,
-        id_mapper: Mapper[_MappedId, _Id],
-        create_mapper: Mapper[_MappedCreate, _A],
-        update_mapper: Mapper[_MappedUpdate, _U],
-        replace_mapper: Mapper[_MappedReplace, _R],
-        item_mapper: Mapper[_I, _MappedItem],
+        id_mapper: Mapper[_MId, _Id],
+        create_mapper: Mapper[_MA, _A],
+        update_mapper: Mapper[_MU, _U],
+        replace_mapper: Mapper[_MR, _R],
+        item_mapper: Mapper[_I, _MI],
     ) -> None:
-        """
-        Initialize the `MappedRepository` instance.
+        """Initialize the `MappedRepository` instance.
 
         Args:
             id_mapper: A mapper to transform the item ID.
@@ -64,28 +69,58 @@ class MappedRepository(
         self.update_mapper = update_mapper
         self.replace_mapper = replace_mapper
 
-    async def add(self, payload: _MappedCreate, **kwargs: Any) -> _MappedItem:
+    async def add(self, payload: _MA, **kwargs: Any) -> _MI:
+        """Add a new item.
+
+        Args:
+            payload (_MA): The payload to use
+
+        Returns:
+            _MI: The newly created item
+        """
         return self.item_mapper(
             await self.repository.add(self.create_mapper(payload), **kwargs)
         )
 
-    async def update(
-        self, item_id: _MappedId, payload: _MappedUpdate, **kwargs: Any
-    ) -> _MappedItem:
+    async def update(self, item_id: _MId, payload: _MU, **kwargs: Any) -> _MI:
+        """Update an item.
+
+        Args:
+            item_id (_MId): The item ID to change
+            payload (_MU): The data to update with
+
+        Returns:
+            _MI: The updated item
+        """
         return self.item_mapper(
             await self.repository.update(
                 self.id_mapper(item_id), self.update_mapper(payload), **kwargs
             )
         )
 
-    async def get_by_id(self, item_id: _MappedId, **kwargs: Any) -> _MappedItem:
+    async def get_by_id(self, item_id: _MId, **kwargs: Any) -> _MI:
+        """Retrieve an item by it's ID.
+
+        Args:
+            item_id (_MId): The ID of the item to retrieve
+
+        Returns:
+            _MI: The item
+        """
         return self.item_mapper(
             await self.repository.get_by_id(self.id_mapper(item_id), **kwargs)
         )
 
-    async def replace(
-        self, item_id: _MappedId, payload: _MappedReplace, **kwargs: Any
-    ) -> _MappedItem:
+    async def replace(self, item_id: _MId, payload: _MR, **kwargs: Any) -> _MI:
+        """Replace an item in the underlying store.
+
+        Args:
+            item_id (_MId): The item ID to replace
+            payload (_MR): The data to replace with
+
+        Returns:
+            _MI: The new item
+        """
         return self.item_mapper(
             await self.repository.replace(
                 self.id_mapper(item_id), self.replace_mapper(payload), **kwargs
@@ -93,6 +128,11 @@ class MappedRepository(
         )
 
     async def get_count(self, **query_filters: Any) -> int:
+        """Retrieve a count of items.
+
+        Returns:
+            int: The item count
+        """
         return await self.repository.get_count(**query_filters)
 
     async def get_list(
@@ -101,7 +141,16 @@ class MappedRepository(
         offset: Optional[int] = None,
         size: Optional[int] = None,
         **query_filters: Any,
-    ) -> List[_MappedItem]:
+    ) -> List[_MI]:
+        """Retrieve a list of items from the undeerlying repository.
+
+        Args:
+            offset (Optional[int], optional): The list offset. Defaults to None.
+            size (Optional[int], optional): The list size. Defaults to None.
+
+        Returns:
+            List[_MI]: A list of items
+        """
         return [
             self.item_mapper(item)
             for item in await self.repository.get_list(
@@ -109,5 +158,10 @@ class MappedRepository(
             )
         ]
 
-    async def remove(self, item_id: _MappedId, **kwargs: Any):
-        return await self.repository.remove(self.id_mapper(item_id), **kwargs)
+    async def remove(self, item_id: _MId, **kwargs: Any):
+        """Remove an item from the underlying repository.
+
+        Args:
+            item_id (_MId): The item ID to be removed.
+        """
+        await self.repository.remove(self.id_mapper(item_id), **kwargs)
